# Refine Source 1.1.3  20221120
# Copyright 2022 by Takahiro Arai. All Rights Reserved.
#
package MT::Plugin::RefineSource;

use strict;
use base qw(MT::Plugin);
use URI;

my $plugin = new MT::Plugin::RefineSource({
	id          => 'refinesource',
	name        => 'Refine Source',
	description => 'Refine Source',
	version     => '1.1.3',
	author_name => 'Takahiro Arai',
	author_link => 'http://www.araif.com/',
	registry => {
		callbacks => {
			'build_page' => \&refine_source_build_page,
			'MT::App::Comments::post_run' => \&refine_source_post_run,
		},
	}
});
MT->add_plugin($plugin);


sub refine_source_post_run {
	my ($cb, $app) = @_;
	
	unless ($app->{no_print_body}) {
		my $content_ref = \$app->{response_content};
		my $site_host = $app->blog->site_url;
		$site_host =~ s%^(.+://[^/]+).*%$1%;
		my $config = $app->config;
		my $page_url = $site_host.$config->CGIPath.$config->CommentScript;
		refine_source($content_ref, $site_host, $page_url);
	}
}

sub refine_source_build_page {
	my ($cb, %args) = @_;
	
	my $content_ref = $args{content};
	my $site_host = $args{blog}->site_url;
	$site_host =~ s%^(.+://[^/]+).*%$1%;
	my $page_url = $site_host.$args{FileInfo}->url;

	refine_source($content_ref, $site_host, $page_url);
}

sub refine_source {
	my ($content_ref, $site_host, $page_url) = @_;

	$page_url =~ s/\?.*//;
	if ($page_url =~ /\.(html|cgi|css|js|xml)$/) {
		# remove space
		$$content_ref =~ s%(<pre[>\s].*?</pre>)|(<textarea[>\s].*?</textarea>)|(\n)\s*%$1$2$3%gs;

		if ($page_url =~ /\.(html|cgi)$/) {
			# convert url
			$$content_ref =~ s%<(a\s[^>]*href|img\s[^>]*src|script\s[^>]*src|link\s[^>]*href|form\s[^>]*action)="($site_host(|/[^"]*)|(/[^"]*))"%'<' . "$1" . '="' . URI->new($site_host.$3.$4)->rel($page_url) . '"'%ge;
		}
	}
}

1;
